SharedPrefProWeb class

The web implementation of SharedPrefProPlatform.

Inheritance

Constructors

SharedPrefProWeb()
Constructs a SharedPrefProWeb.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear() Future<bool>
Clears all values.
override
containsKey(String key) Future<bool>
Returns true if the key exists.
override
get(String key) Future
Gets a value by key.
override
getKeys() Future<List<String>>
Returns all keys.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove(String key) Future<bool>
Removes a value by key.
override
setBool(String key, bool value) Future<bool>
Sets a boolean value.
override
setDouble(String key, double value) Future<bool>
Sets a double value.
override
setInt(String key, int value) Future<bool>
Sets an integer value.
override
setString(String key, String value) Future<bool>
Sets a string value.
override
setStringList(String key, List<String> value) Future<bool>
Sets a list of strings.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

registerWith(Registrar registrar) → void
Registers this class as the default instance of SharedPrefProPlatform.