containsKey method
Returns true if the local storage contains the given key.
Note: If the key exists but has expired, it will still return true
until get or remove is called, or use isExpired to check.
Implementation
Future<bool> containsKey(String key) async {
return SharedPrefProPlatform.instance.containsKey(key);
}