SharedPrefProPlatform class abstract
The interface that implementations of shared_pref_pro must implement.
- Inheritance
-
- Object
- PlatformInterface
- SharedPrefProPlatform
- Implementers
Constructors
- Constructs a SharedPrefProPlatform.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clear(
) → Future< bool> - Clears all values.
-
containsKey(
String key) → Future< bool> - Returns true if the key exists.
-
get(
String key) → Future - Gets a value by key.
-
getKeys(
) → Future< List< String> > - Returns all keys.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
remove(
String key) → Future< bool> - Removes a value by key.
-
setBool(
String key, bool value) → Future< bool> - Sets a boolean value.
-
setDouble(
String key, double value) → Future< bool> - Sets a double value.
-
setInt(
String key, int value) → Future< bool> - Sets an integer value.
-
setString(
String key, String value) → Future< bool> - Sets a string value.
-
setStringList(
String key, List< String> value) → Future<bool> - Sets a list of strings.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ SharedPrefProPlatform
-
The default instance of SharedPrefProPlatform to use.
getter/setter pair